/*******************************************
 *
 * $GAMGI/src/gtk/gamgi_copy.h
 *
 * Copyright (C) 2001, 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

void gamgi_gtk_orbital_copy (GtkWidget *widget, void *data);

void gamgi_gtk_arrow_copy (GtkWidget *widget, void *data);

void gamgi_gtk_shape_copy (GtkWidget *widget, void *data);

void gamgi_gtk_graph_copy (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Not implemented yet.

 *************
 * Rationale *
 *************/
